@@ -138,10 +138,7 @@ class DesktopTest(unittest.TestCase):
 
     def _open_containment_config_dialog(self) -> None:
         # Alt+D, S
-        actions = ActionChains(self.driver)
-        actions.key_down(Keys.ALT).send_keys("d").perform()
-        time.sleep(0.5)
-        actions.send_keys("s").key_up(Keys.ALT).perform()
+        ActionChains(self.driver).key_down(Keys.ALT).send_keys("d").pause(0.5).send_keys("s").key_up(Keys.ALT).perform()
         WebDriverWait(self.driver, 30).until(EC.presence_of_element_located((AppiumBy.NAME, "Wallpaper type:")))
 
     def test_0_panel_ready(self) -> None:
@@ -247,6 +244,43 @@ class DesktopTest(unittest.TestCase):
         session_bus.send_message_with_reply_sync(message, Gio.DBusSendMessageFlags.NONE, 1000)
         wait.until(EC.presence_of_element_located((AppiumBy.NAME, "Install Software")))
 
+    def test_5_sentry_3516_load_layout(self) -> None:
+        """
+        ShellCorona::loadLookAndFeelDefaultLayout -> ShellCorona::unload() -> qDeleteAll(panelViews) -> QWindow::visibleChanged -> rectNotify() -> 💣
+        @see https://bugreports.qt.io/browse/QTBUG-118841
+        """
+        kickoff_element = self.driver.find_element(AppiumBy.NAME, "Application Launcher")
+        session_bus = Gio.bus_get_sync(Gio.BusType.SESSION)
+        # LookAndFeelManager::save
+        message: Gio.DBusMessage = Gio.DBusMessage.new_method_call("org.kde.plasmashell", "/PlasmaShell", "org.kde.PlasmaShell", "loadLookAndFeelDefaultLayout")
+        message.set_body(GLib.Variant("(s)", ["Breeze Dark"]))
+        session_bus.send_message_with_reply_sync(message, Gio.DBusSendMessageFlags.NONE, 5000)
+        self.assertFalse(kickoff_element.is_displayed())
+        self.driver.find_element(AppiumBy.NAME, "Application Launcher")
+
+    def test_6_bug_query_accent_color_binding_loop(self) -> None:
+        """
+        Don't use binding as usedInAccentColor may be disabled immediately after a query from kcm_colors.
+
+        The call order is:
+        1. desktop.usedInAccentColor: true -> wallpaperColors.active: true
+        2. Kirigami.ImageColors.update()
+        3. Kirigami.ImageColors emits paletteChanged()
+        5. If binding is used, ShellCorona::colorChanged is emitted immediately in the same context after desktop.accentColor is updated
+           -> desktop.usedInAccentColor: false -> desktop.accentColor: "transparent" (binding restoration).
+        6. The second time querying the accent color, the QML engine will report binding loop detected in desktop.usedInAccentColor,
+           and desktop.accentColor will return "transparent" directly before any accent color from the wallpaper is extracted.
+        """
+        session_bus = Gio.bus_get_sync(Gio.BusType.SESSION)
+        # Send the same request twice to check binding loop
+        for i in range(2):
+            print(f"sending message {i}", file=sys.stderr)
+            message: Gio.DBusMessage = Gio.DBusMessage.new_method_call("org.kde.plasmashell", "/PlasmaShell", "org.kde.PlasmaShell", "color")
+            reply, _ = session_bus.send_message_with_reply_sync(message, Gio.DBusSendMessageFlags.NONE, 1000)
+            self.assertEqual(reply.get_signature(), "u")
+            self.assertGreater(reply.get_body().get_child_value(0).get_uint32(), 0)
+            print("done sending message", file=sys.stderr)
+
 
 if __name__ == '__main__':
     unittest.main()
