@@ -8,6 +8,7 @@
 
 #include <KDEDModule>
 #include <QStringList>
+#include <optional>
 
 #include "bindings.h"
 #include "keyboard_dbus.h"
@@ -27,12 +28,14 @@ class Q_DECL_EXPORT KeyboardDaemon : public KDEDModule
     KeyboardLayoutActionCollection *actionCollection;
     XInputEventNotifier *xEventNotifier;
     LayoutMemory layoutMemory;
+    std::optional<uint> lastUsedLayout;
     const Rules *rules;
 
     void registerListeners();
     void registerShortcut();
     void unregisterListeners();
     void unregisterShortcut();
+    void setLastUsedLayoutValue(uint newValue);
 
 private Q_SLOTS:
     void configureKeyboard();
@@ -46,7 +49,7 @@ public Q_SLOTS:
     Q_SCRIPTABLE void switchToPreviousLayout();
     Q_SCRIPTABLE bool setLayout(uint index);
     Q_SCRIPTABLE uint getLayout() const;
-    Q_SCRIPTABLE QVector<LayoutNames> getLayoutsList() const;
+    Q_SCRIPTABLE QList<LayoutNames> getLayoutsList() const;
 
 Q_SIGNALS:
     Q_SCRIPTABLE void layoutChanged(uint index);
