@@ -8,10 +8,11 @@
 #pragma once
 
 #include <KPackage/Package>
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
 
 #include <QJsonArray>
 #include <QJsonValue>
+#include <QSortFilterProxyModel>
 
 class QStandardItemModel;
 
@@ -52,18 +53,18 @@ class LookAndFeelGroup : public QObject
     Q_OBJECT
     Q_PROPERTY(QString id READ id CONSTANT)
     Q_PROPERTY(QString name READ name CONSTANT)
-    Q_PROPERTY(QString thumbnail READ thumbnail CONSTANT)
+    Q_PROPERTY(QUrl thumbnail READ thumbnail CONSTANT)
 
 public:
     LookAndFeelGroup(QObject *parent = nullptr);
     QString id() const;
     QString name() const;
-    QString thumbnail() const;
+    QUrl thumbnail() const;
 
     KPackage::Package m_package;
 };
 
-class KCMLandingPage : public KQuickAddons::ManagedConfigModule
+class KCMLandingPage : public KQuickManagedConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(MostUsedModel *mostUsedModel READ mostUsedModel CONSTANT)
@@ -72,7 +73,7 @@ class KCMLandingPage : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(LookAndFeelGroup *defaultDarkLookAndFeel READ defaultDarkLookAndFeel CONSTANT)
 
 public:
-    KCMLandingPage(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    KCMLandingPage(QObject *parent, const KPluginMetaData &metaData);
     ~KCMLandingPage() override
     {
     }
