@@ -8,11 +8,7 @@
 
 #include <QObject>
 #include <QString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
 #include <X11/Xdefs.h>
 
