@@ -3,9 +3,10 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#include "plugin.h"
 #include "kcm/configcontainer.h"
 
+#include <KPluginFactory>
+
 K_PLUGIN_CLASS_WITH_JSON(ConfigContainer, "kcm_mouse.json")
 
 #include <plugin.moc>
