@@ -21,7 +21,7 @@ class RecentFilesKcm : public KCModule
 {
     Q_OBJECT
 public:
-    explicit RecentFilesKcm(QWidget *parent, QVariantList args);
+    explicit RecentFilesKcm(QObject *parent, const KPluginMetaData &data);
     ~RecentFilesKcm() override;
 
     KCoreConfigSkeleton *pluginConfig();
