@@ -5,19 +5,19 @@
 */
 #pragma once
 
-#include <Plasma/DataEngine>
+#include <Plasma5Support/DataEngine>
 
 class OrgKdeTouchpadInterface;
 
-class TouchpadEngine : public Plasma::DataEngine
+class TouchpadEngine : public Plasma5Support::DataEngine
 {
     Q_OBJECT
 
 public:
-    TouchpadEngine(QObject *parent, const QVariantList &args);
+    TouchpadEngine(QObject *parent);
     ~TouchpadEngine();
 
-    Plasma::Service *serviceForSource(const QString &source) override;
+    Plasma5Support::Service *serviceForSource(const QString &source) override;
 
 private Q_SLOTS:
     void workingTouchpadFoundChanged(bool);
